==> tinyerp-server_3.4.2.orig.tar.gz: tinyerp-server-3.4.2/bin/addons/account/project/wizard/wizard_account_analytic_cost_ledger_for_journal_report.py <==
##############################################################################
#
# Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import time
import wizard

_form = '''<?xml version="1.0"?>
<form string="Select period">
	<separator string="Cost Legder for period" colspan="4"/>
	<field name="date1"/>
	<field name="date2"/>
	<separator string="and Journals" colspan="4"/>
	<field name="journal" colspan="4"/>
</form>'''

_fields = {
	'date1': {'string':'Start of period', 'type':'date', 'required':True, 'default': lambda *a: time.strftime('%Y-01-01')},
	'date2': {'string':'End of period', 'type':'date', 'required':True, 'default': lambda *a: time.strftime('%Y-%m-%d')},
	'journal': {'string':'Journals','type':'many2many', 'relation':'account.analytic.journal'},
}

class wizard_report(wizard.interface):
	states = {
		'init': {
			'actions': [], 
			'result': {'type':'form', 'arch':_form, 'fields':_fields, 'state':[('report','Print'), ('end','Cancel')]}
		},
		'report': {
			'actions': [],
			'result': {'type':'print', 'report':'account.analytic.account.cost_ledger_for_journal', 'state':'end'}
		}
	}
wizard_report('account.analytic.account.quantity_cost_ledger.report')

==> tinyerp-server_4.2.2.orig.tar.gz: tinyerp-server-4.2.2/bin/addons/account/project/wizard/wizard_account_analytic_cost_ledger_for_journal_report.py <==
##############################################################################
#
# Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import time
import wizard

_form = '''<?xml version="1.0"?>
<form string="Select period">
	<separator string="Cost Legder for period" colspan="4"/>
	<field name="date1"/>
	<field name="date2"/>
	<separator string="and Journals" colspan="4"/>
	<field name="journal" colspan="4"/>
</form>'''

_fields = {
	'date1': {'string':'Start of period', 'type':'date', 'required':True, 'default': lambda *a: time.strftime('%Y-01-01')},
	'date2': {'string':'End of period', 'type':'date', 'required':True, 'default': lambda *a: time.strftime('%Y-%m-%d')},
	'journal': {'string':'Journals','type':'many2many', 'relation':'account.analytic.journal'},
}


class wizard_report(wizard.interface):
	states = {
		'init': {
			'actions': [],
			'result': {
				'type': 'form',
				'arch': _form,
				'fields': _fields,
				'state': [
					('end','Cancel'),
					('report','Print')
				]
			}
		},
		'report': {
			'actions': [],
			'result': {
				'type': 'print',
				'report': 'account.analytic.account.quantity_cost_ledger',
				'state': 'end'
			}
		},
	}

wizard_report('account.analytic.account.quantity_cost_ledger.report')
